@@ -50,7 +50,9 @@
 #include <QtCore/QVariant>
 #include <QtCore/QSysInfo>
 #include <QtCore/QLibraryInfo>
-#include <QtCore/QProcessEnvironment>
+#if QT_CONFIG(processenvironment)
+#  include <QtCore/QProcessEnvironment>
+#endif
 #include <QtCore/QTextStream>
 #include <QtCore/QStandardPaths>
 #include <QtCore/QDir>
@@ -62,9 +64,14 @@
 #include <qpa/qplatformintegration.h>
 #include <qpa/qplatformscreen.h>
 #include <qpa/qplatformtheme.h>
+#include <qpa/qplatformthemefactory_p.h>
 #include <qpa/qplatformnativeinterface.h>
 #include <private/qhighdpiscaling_p.h>
 
+#ifdef QT_WIDGETS_LIB
+#  include <QtWidgets/QStyleFactory>
+#endif
+
 #include <algorithm>
 
 QT_BEGIN_NAMESPACE
@@ -174,7 +181,7 @@ void dumpGlInfo(QTextStream &str, bool listExtensions)
             QList<QByteArray> extensionList = context.extensions().toList();
             std::sort(extensionList.begin(), extensionList.end());
             str << " \nFound " << extensionList.size() << " extensions:\n";
-            foreach (const QByteArray &extension, extensionList)
+            for (const QByteArray &extension : qAsConst(extensionList))
                 str << "  " << extension << '\n';
         }
     } else {
@@ -347,7 +354,8 @@ QString qtDiag(unsigned flags)
 #ifndef QT_NO_PROCESS
     const QProcessEnvironment systemEnvironment = QProcessEnvironment::systemEnvironment();
     str << "\nEnvironment:\n";
-    foreach (const QString &key, systemEnvironment.keys()) {
+    const QStringList keys = systemEnvironment.keys();
+    for (const QString &key : keys) {
         if (key.startsWith(QLatin1Char('Q')))
            str << "  " << key << "=\"" << systemEnvironment.value(key) << "\"\n";
     }
@@ -396,7 +404,8 @@ QString qtDiag(unsigned flags)
     DUMP_STANDARDPATH(str, AppConfigLocation)
 
     str << "\nFile selectors (increasing order of precedence):\n ";
-    foreach (const QString &s, QFileSelector().allSelectors())
+    const QStringList allSelectors = QFileSelector().allSelectors();
+    for (const QString &s : allSelectors)
         str << ' ' << s;
 
     str << "\n\nNetwork:\n  ";
@@ -465,16 +474,21 @@ QString qtDiag(unsigned flags)
 
     const QPlatformTheme *platformTheme = QGuiApplicationPrivate::platformTheme();
     str << "\nTheme:"
-           "\n  Available    : " << platformIntegration->themeNames()
-        << "\n  Styles       : " << platformTheme->themeHint(QPlatformTheme::StyleNames).toStringList();
+           "\n  Platforms requested : " << platformIntegration->themeNames()
+        << "\n            available : " << QPlatformThemeFactory::keys()
+#ifdef QT_WIDGETS_LIB
+        << "\n  Styles requested    : " << platformTheme->themeHint(QPlatformTheme::StyleNames).toStringList()
+        << "\n         available    : " << QStyleFactory::keys()
+#endif
+           ;
     const QString iconTheme = platformTheme->themeHint(QPlatformTheme::SystemIconThemeName).toString();
     if (!iconTheme.isEmpty()) {
-        str << "\n  Icon theme   : " << iconTheme
+        str << "\n  Icon theme          : " << iconTheme
             << ", " << platformTheme->themeHint(QPlatformTheme::SystemIconFallbackThemeName).toString()
-            << " from " << platformTheme->themeHint(QPlatformTheme::IconThemeSearchPaths).toStringList() << '\n';
+            << " from " << platformTheme->themeHint(QPlatformTheme::IconThemeSearchPaths).toStringList();
     }
     if (const QFont *systemFont = platformTheme->font())
-        str << "\n  System font  : " << *systemFont<< '\n';
+        str << "\n  System font         : " << *systemFont<< '\n';
 
     if (platformTheme->usePlatformNativeDialog(QPlatformTheme::FileDialog))
         str << "  Native file dialog\n";
@@ -522,6 +536,9 @@ QString qtDiag(unsigned flags)
         str << '#' << ' ' << s << " \"" << screen->name() << '"'
                   << " Depth: " << screen->depth()
                   << " Primary: " <<  (screen == QGuiApplication::primaryScreen() ? "yes" : "no")
+            << "\n  Manufacturer: " << screen->manufacturer()
+            << "\n  Model: " << screen->model()
+            << "\n  Serial number: " << screen->serialNumber()
             << "\n  Geometry: " << geometry;
         if (geometry != nativeGeometry)
             str << " (native: " << nativeGeometry << ')';
@@ -553,7 +570,7 @@ QString qtDiag(unsigned flags)
     const QList<const QTouchDevice *> touchDevices = QTouchDevice::devices();
     if (!touchDevices.isEmpty()) {
         str << "Touch devices: " << touchDevices.size() << '\n';
-        foreach (const QTouchDevice *device, touchDevices) {
+        for (const QTouchDevice *device : touchDevices) {
             str << "  " << (device->type() == QTouchDevice::TouchScreen ? "TouchScreen" : "TouchPad")
                 << " \"" << device->name() << "\", max " << device->maximumTouchPoints()
                 << " touch points, capabilities:";
